Visualize API
=============

.. autofunction:: visualize.geojsonio_contents

.. autofunction:: visualize.get_geojsonio_trajectory

.. autofunction:: visualize.get_geojson_trajectories

.. autofunction:: visualize._swap_coordinates
